@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 
+from .exceptions import ValidationError
 from .utils import digattr
 
 from decimal import Decimal
@@ -11,14 +12,18 @@ except ImportError:
     # For Django1.4
     from django.utils.encoding import force_unicode as force_text
 
+class NoDefault(object):
+    '''Indicates no default value was provided.'''
+
 class Field(object):
     type_class = None
 
-    def __init__(self, attribute=None, default=None, readonly=False,
-                 **kwargs):
+    def __init__(self, attribute=None, default=NoDefault, readonly=False,
+                 null=True, **kwargs):
         self.attribute = attribute
         self.default = default
         self.readonly = readonly
+        self.null = null
         self.kwargs = kwargs
 
     def _get_attrname(self, name):
@@ -35,6 +40,8 @@ class Field(object):
     def deflate(self, name, obj, data, **kwargs):
         src = self._get_attrname(name)
         value = digattr(obj, src, self.default)
+        if value is NoDefault:
+            return
         if value is not None:
             value = self.reduce(value, **kwargs)
         data[name] = value
@@ -45,9 +52,20 @@ class Field(object):
         dest = self._get_attrname(name)
         try:
             value = data[name]
-            obj[dest] = self.restore(value, **kwargs)
         except KeyError:
-            pass
+            if self.default is not NoDefault and not instance in kwargs:
+                obj[dest] = self.default
+            return
+
+        if value is not None:
+            try:
+                value = self.restore(value, **kwargs)
+            except ValueError:
+                raise ValidationError("Field '%s' received invalid value: %r" % (name, value))
+        elif not self.null:
+            raise ValidationError("Field '%s' must not be None." % name)
+
+        obj[dest] = value
 
 
 class BooleanField(Field):
